import{m as F,a as U,u as R,b as y,c as I}from"./VCheckboxBtn-b3446400.js";import{p as h,az as C,g,h as G,ap as S,c as v,aI as w,l as V,n as f,d as H,e as z,r as D}from"./index-ab7e5b57.js";import{i as T,a as M,n as N,d as W,p as j,x as q,y as E,H as J}from"./forwardRefs-d370b8e9.js";import{m as K,a as L,f as x}from"./VMenu-9ab9e35f.js";const Q=h({...F(),...C(U(),["inline"])},"VCheckbox"),ae=g()({name:"VCheckbox",inheritAttrs:!1,props:Q(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,n){let{attrs:t,slots:a}=n;const o=G(e,"modelValue"),{isFocused:i,focus:l,blur:r}=R(e),u=S(),s=v(()=>e.id||`checkbox-${u}`);return T(()=>{const[b,P]=w(t),k=y.filterProps(e),c=I.filterProps(e);return V(y,f({class:["v-checkbox",e.class]},b,k,{modelValue:o.value,"onUpdate:modelValue":d=>o.value=d,id:s.value,focused:i.value,style:e.style}),{...a,default:d=>{let{id:m,messagesId:p,isDisabled:O,isReadonly:$}=d;return V(I,f(c,{id:m.value,"aria-describedby":p.value,disabled:O.value,readonly:$.value},P,{modelValue:o.value,"onUpdate:modelValue":B=>o.value=B,onFocus:l,onBlur:r}),a)}})}),{}}});const A=Symbol.for("vuetify:v-item-group"),X=h({...M(),...N({selectedClass:"v-item--selected"}),...W(),...H()},"VItemGroup"),oe=g()({name:"VItemGroup",props:X(),emits:{"update:modelValue":e=>!0},setup(e,n){let{slots:t}=n;const{themeClasses:a}=z(e),{isSelected:o,select:i,next:l,prev:r,selected:u}=j(e,A);return()=>V(e.tag,{class:["v-item-group",a.value,e.class],style:e.style},{default:()=>{var s;return[(s=t.default)==null?void 0:s.call(t,{isSelected:o,select:i,next:l,prev:r,selected:u.value})]}})}}),se=g()({name:"VItem",props:q(),emits:{"group:selected":e=>!0},setup(e,n){let{slots:t}=n;const{isSelected:a,select:o,toggle:i,selectedClass:l,value:r,disabled:u}=E(e,A);return()=>{var s;return(s=t.default)==null?void 0:s.call(t,{isSelected:a.value,selectedClass:l.value,select:o,toggle:i,value:r.value,disabled:u.value})}}});const Y=h({id:String,text:String,...C(K({closeOnBack:!1,location:"end",locationStrategy:"connected",eager:!0,minWidth:0,offset:10,openOnClick:!1,openOnHover:!0,origin:"auto",scrim:!1,scrollStrategy:"reposition",transition:!1}),["absolute","persistent"])},"VTooltip"),le=g()({name:"VTooltip",props:Y(),emits:{"update:modelValue":e=>!0},setup(e,n){let{slots:t}=n;const a=G(e,"modelValue"),{scopeId:o}=L(),i=S(),l=v(()=>e.id||`v-tooltip-${i}`),r=D(),u=v(()=>e.location.split(" ").length>1?e.location:e.location+" center"),s=v(()=>e.origin==="auto"||e.origin==="overlap"||e.origin.split(" ").length>1||e.location.split(" ").length>1?e.origin:e.origin+" center"),b=v(()=>e.transition?e.transition:a.value?"scale-transition":"fade-transition"),P=v(()=>f({"aria-describedby":l.value},e.activatorProps));return T(()=>{const k=x.filterProps(e);return V(x,f({ref:r,class:["v-tooltip",e.class],style:e.style,id:l.value},k,{modelValue:a.value,"onUpdate:modelValue":c=>a.value=c,transition:b.value,absolute:!0,location:u.value,origin:s.value,persistent:!0,role:"tooltip",activatorProps:P.value,_disableGlobalStack:!0},o),{activator:t.activator,default:function(){var p;for(var c=arguments.length,d=new Array(c),m=0;m<c;m++)d[m]=arguments[m];return((p=t.default)==null?void 0:p.call(t,...d))??e.text}})}),J({},r)}});export{le as V,ae as a,oe as b,se as c};
