import{v as n,Q as l,aa as c,c as u,y as h,E as f,l as w,K as a,L as b}from"./index-ab7e5b57.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-14f8f800.js";import"./ListviewItem-249726c3.js";import"./VBadge-babce8af.js";import"./ListItem-fd009900.js";import"./forwardRefs-d370b8e9.js";import"./VMenu-9ab9e35f.js";import"./VCheckboxBtn-b3446400.js";import"./VSlideGroup-6eee8f80.js";import"./VCard-b678de17.js";import"./VCardText-2b5487e9.js";import"./VTooltip-775ce0c0.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-f3f21d77.js";import"./contextmenu-81dbffb6.js";import"./Alert-7da447ab.js";import"./Container-2bd44608.js";/* empty css              */import"./VToolbar-93b44e3d.js";import"./VTextField-864bfd83.js";import"./VVirtualScroll-506acdd4.js";const A=n({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:o}=l();c();const p=u(()=>!t.path||t.path=="root"?o("browse"):a("bp6")?o("browse")+" | "+t.path:a("bp3")?t.path:o("browse")),i=async function(e){const r=[];return await b.browse(t.path,m=>{r.push(...m)}),r};return(e,r)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:e.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{A as default};
